@@ -1,6 +1,6 @@
 /*
   eXosip - This is the eXtended osip library.
-  Copyright (C) 2002, 2003  Aymeric MOIZARD  - jack@atosc.org
+  Copyright (C) 2002,2003,2004,2005,2006,2007  Aymeric MOIZARD  - jack@atosc.org
   
   eXosip is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ _eXosip_event_fill_messages (eXosip_event_t * je, osip_transaction_t * tr)
                                   "failed to clone ACK for event\n"));
         }
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 eXosip_event_t *
@@ -90,6 +90,8 @@ eXosip_event_init_for_call (int type, eXosip_call_t * jc,
   return je;
 }
 
+#ifndef MINISIZE
+
 eXosip_event_t *
 eXosip_event_init_for_subscribe (int type, eXosip_subscribe_t * js,
                                  eXosip_dialog_t * jd, osip_transaction_t * tr)
@@ -146,6 +148,8 @@ eXosip_event_init_for_notify (int type, eXosip_notify_t * jn,
   return je;
 }
 
+#endif
+
 eXosip_event_t *
 eXosip_event_init_for_reg (int type, eXosip_reg_t * jr, osip_transaction_t * tr)
 {
@@ -184,7 +188,7 @@ eXosip_event_init (eXosip_event_t ** je, int type)
 {
   *je = (eXosip_event_t *) osip_malloc (sizeof (eXosip_event_t));
   if (*je == NULL)
-    return -1;
+    return OSIP_NOMEM;
 
   memset (*je, 0, sizeof (eXosip_event_t));
   (*je)->type = type;
@@ -321,7 +325,7 @@ eXosip_event_init (eXosip_event_t ** je, int type)
       (*je)->textinfo[0] = '\0';
     }
 #endif
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -357,29 +361,15 @@ report_call_event (int evt, eXosip_call_t * jc,
   report_event (je, NULL);
 }
 
-void
-report_options_event (int evt, osip_transaction_t * tr)
-{
-  eXosip_event_t *je;
-
-  eXosip_event_init (&je, evt);
-  if (je == NULL)
-    return;
-
-  if (tr != NULL)
-    je->tid = tr->transactionid;
-
-  _eXosip_event_fill_messages (je, tr);
-  report_event (je, NULL);
-}
-
 int
 eXosip_event_add (eXosip_event_t * je)
 {
   int i = osip_fifo_add (eXosip.j_events, (void *) je);
 
+#ifdef OSIP_MT
 #if !defined (_WIN32_WCE)
   osip_cond_signal ((struct osip_cond *) eXosip.j_cond);
+#endif
 #endif
 
   __eXosip_wakeup_event ();
@@ -421,6 +411,25 @@ __eXosip_clock_gettime (unsigned int clock_id, struct timespec *time)
 #endif
 #endif
 
+#ifndef OSIP_MT
+
+eXosip_event_t *
+eXosip_event_wait (int tv_s, int tv_ms)
+{
+  eXosip_event_t *je = NULL;
+  je = (eXosip_event_t *) osip_fifo_tryget (eXosip.j_events);
+  if (je != NULL)
+    return je;
+
+  eXosip_lock ();
+  eXosip_retransmit_lost200ok ();
+  eXosip_unlock ();
+
+  return NULL;
+}
+
+#else
+
 eXosip_event_t *
 eXosip_event_wait (int tv_s, int tv_ms)
 {
@@ -476,23 +485,40 @@ eXosip_event_wait (int tv_s, int tv_ms)
     FD_SET (jpipe_get_read_descr (eXosip.j_socketctl_event), &fdset);
 #endif
     max = jpipe_get_read_descr (eXosip.j_socketctl_event);
-    tv.tv_sec = tv_s;
-    tv.tv_usec = tv_ms * 1000;
 
     je = (eXosip_event_t *) osip_fifo_tryget (eXosip.j_events);
     if (je != NULL)
       return je;
 
-	eXosip_lock();
-	eXosip_retransmit_lost200ok();
-	eXosip_unlock();
+    tv.tv_sec = 0;
+    tv.tv_usec = 0;
+    i = select (max + 1, &fdset, NULL, NULL, &tv);
+    if (FD_ISSET (jpipe_get_read_descr (eXosip.j_socketctl_event), &fdset))
+      {
+        char buf[500];
+        int c = jpipe_read (eXosip.j_socketctl_event, buf, 499);
+      }
+
+    eXosip_lock ();
+    eXosip_retransmit_lost200ok ();
+    eXosip_unlock ();
+
+    FD_ZERO (&fdset);
+#if defined (WIN32) || defined (_WIN32_WCE)
+    FD_SET ((unsigned int) jpipe_get_read_descr (eXosip.j_socketctl_event),
+            &fdset);
+#else
+    FD_SET (jpipe_get_read_descr (eXosip.j_socketctl_event), &fdset);
+#endif
+    tv.tv_sec = tv_s;
+    tv.tv_usec = tv_ms * 1000;
 
     if (tv_s == 0 && tv_ms == 0)
       return NULL;
 
     i = select (max + 1, &fdset, NULL, NULL, &tv);
     if (i <= 0)
-      return 0;
+      return OSIP_SUCCESS;
 
     if (eXosip.j_stop_ua)
       return NULL;
@@ -500,8 +526,7 @@ eXosip_event_wait (int tv_s, int tv_ms)
     if (FD_ISSET (jpipe_get_read_descr (eXosip.j_socketctl_event), &fdset))
       {
         char buf[500];
-
-        jpipe_read (eXosip.j_socketctl_event, buf, 499);
+        int c = jpipe_read (eXosip.j_socketctl_event, buf, 499);
       }
 
     je = (eXosip_event_t *) osip_fifo_tryget (eXosip.j_events);
@@ -513,11 +538,22 @@ eXosip_event_wait (int tv_s, int tv_ms)
   return je;
 }
 
+int
+eXosip_event_geteventsocket (void)
+{
+  return jpipe_get_read_descr (eXosip.j_socketctl_event);
+}
+
 eXosip_event_t *
 eXosip_event_get ()
 {
   eXosip_event_t *je;
 
+  char buf[500];
+  jpipe_read (eXosip.j_socketctl_event, buf, 499);
+
   je = (eXosip_event_t *) osip_fifo_get (eXosip.j_events);
   return je;
 }
+
+#endif
